.. romancal documentation master file
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

:ref:`genindex`  |  :ref:`modindex`

==============================================
The Roman Space Telescope Calibration Pipeline
==============================================

.. image:: _static/roman_logo_black_w200px.png
   :align: center
   :alt: Nancy Roman Space Telescope

.. include:: roman/introduction.rst

.. toctree::
   :caption: RomanCal Pipeline
   :maxdepth: 2

   roman/pipeline_installation.rst
   roman/pipeline_run.rst
   roman/pipeline_steps.rst
   roman/pipeline_ref_files.rst
   roman/pipeline_parameters.rst
   roman/pipeline_naming_conventions.rst
   roman/error_propagation/index.rst

.. toctree::
   :caption: RomanCal Package Index
   :maxdepth: 3

   roman/package_index.rst

.. toctree::
   :caption: Datamodels
   :maxdepth: 3

   roman/datamodels/index.rst

.. toctree::
   :caption: Additional Information
   :maxdepth: 1
